"""
Django settings for mojec_msh_service project.

Generated by 'django-admin startproject' using Django 3.2.7.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

import os
from pathlib import Path
from mojec_core.settings import *
# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = os.getenv("DEBUG") == "true"

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'rest_framework_simplejwt',
    'mojec_core.app'
]
# git+https://github.com/africa-prudential/mojec-py-core.git@develop
# git+https://github.com/beatsbears/steg.git@develop#egg=steg
ROOT_URLCONF = 'mojec_msh_service.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'mojec_msh_service.wsgi.application'


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = '/static/'



# Generated by Django 3.2.7 on 2022-06-26 15:43

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0010_alter_config_service'),
    ]

    operations = [
        migrations.CreateModel(
            name='Earning',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('deletedViaCascade', models.BooleanField(default=False, editable=False)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('deleted', models.BooleanField(default=False)),
                ('deletedById', models.UUIDField(blank=True, null=True)),
                ('deletedAt', models.DateTimeField(blank=True, db_column='deletedAt', null=True)),
                ('createdAt', models.DateTimeField(auto_now_add=True, db_column='createdAt')),
                ('updatedAt', models.DateTimeField(auto_now=True, db_column='updatedAt')),
                ('transactionRef', models.CharField(blank=True, db_column='transactionRef', max_length=255, null=True)),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('balanceBefore', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('balanceAfter', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('createdBy', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'Earnings',
            },
        ),
        migrations.RemoveField(
            model_name='transactionlog',
            name='email',
        ),
        migrations.RemoveField(
            model_name='transactionlog',
            name='name',
        ),
        migrations.RemoveField(
            model_name='transactionlog',
            name='recipient',
        ),
        migrations.RemoveField(
            model_name='transactionlog',
            name='service',
        ),
        migrations.RemoveField(
            model_name='transactionlog',
            name='serviceDescription',
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='transactionType',
            field=models.CharField(choices=[('wallet-topup', 'wallet-topup'), ('wallet-withdrawal', 'wallet-withdrawal'), ('kyc-verification', 'kyc-verification'), ('meter-vend', 'meter-vend'), ('buy-meter', 'buy-meter'), ('service-order-commitment', 'service-order-commitment'), ('service-order-complete', 'service-order-complete'), ('others', 'others')], default='', max_length=30),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='transactionlog',
            name='workOrder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder'),
        ),
        migrations.DeleteModel(
            name='Payment',
        ),
        migrations.AddField(
            model_name='earning',
            name='transactionLog',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.transactionlog'),
        ),
        migrations.AddField(
            model_name='earning',
            name='workOrder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.workorder'),
        ),
    ]



# Generated by Django 3.2.7 on 2022-07-14 05:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0016_powervend'),
    ]

    operations = [
        migrations.AddField(
            model_name='workorder',
            name='agentAssignedAt',
            field=models.DateTimeField(blank=True, db_column='agentAssignedAt', null=True),
        ),
        migrations.AlterField(
            model_name='wallethistory',
            name='type',
            field=models.CharField(blank=True, choices=[('earnings', 'earnings'), ('deposit', 'deposit'), ('withdrawal', 'withdrawal'), ('payment', 'payment')], max_length=30, null=True),
        ),
    ]



from django.db import models
from .base import BaseModelAbstract
from .payment import PaymentVendor


class Card(BaseModelAbstract, models.Model):
    signature = models.CharField(max_length=255, blank=True, null=True)
    email = models.CharField(max_length=255, blank=True, null=True)
    paymentVendor = models.ForeignKey(PaymentVendor,
                                      on_delete=models.SET_NULL,
                                      null=True, blank=True)
    authorization = models.JSONField(blank=True, null=True)

    class Meta:
        db_table = 'Cards'

# {
#     "bin": "408408",
#     "bank": "TEST BANK",
#     "brand": "visa",
#     "last4": "4081",
#     "channel": "card",
#     "exp_year": "2030",
#     "reusable": true,
#     "card_type": "visa ",
#     "exp_month": "12",
#     "signature": "SIG_QkKdsx2GPbL6GMLAx7Og",
#     "account_name": null,
#     "country_code": "NG",
#     "authorization_code": "AUTH_c5ad99qtsf"
# }



from django.db import models

from .base import BaseModelAbstract


class MeansOfIdentification(BaseModelAbstract, models.Model):
    name = models.CharField(max_length=255, blank=False, null=False)
    active = models.BooleanField(default=True)

    class Meta:
        db_table = 'MeansOfIdentifications'





# Generated by Django 3.2.7 on 2022-06-24 19:26

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0008_auto_20220623_0423'),
    ]

    operations = [
        migrations.RenameField(
            model_name='disco',
            old_name='name',
            new_name='longName',
        ),
        migrations.RemoveField(
            model_name='disco',
            name='description',
        ),
        migrations.AddField(
            model_name='disco',
            name='shortName',
            field=models.CharField(default='', max_length=10),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='user',
            name='employerAddress',
            field=models.TextField(blank=True, db_column='employerAddress', null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='employerName',
            field=models.CharField(blank=True, db_column='employerName', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='idNumber',
            field=models.CharField(blank=True, db_column='idNumber', max_length=30, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='idType',
            field=models.CharField(blank=True, db_column='idType', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='landlordAddress',
            field=models.TextField(blank=True, db_column='landlordAddress', null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='landlordName',
            field=models.CharField(blank=True, db_column='landlordName', max_length=255, null=True),
        ),
        migrations.CreateModel(
            name='BusinessUnit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('deletedViaCascade', models.BooleanField(default=False, editable=False)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('deleted', models.BooleanField(default=False)),
                ('deletedById', models.UUIDField(blank=True, null=True)),
                ('deletedAt', models.DateTimeField(blank=True, db_column='deletedAt', null=True)),
                ('createdAt', models.DateTimeField(auto_now_add=True, db_column='createdAt')),
                ('updatedAt', models.DateTimeField(auto_now=True, db_column='updatedAt')),
                ('name', models.CharField(max_length=255)),
                ('location', models.TextField(blank=True, null=True)),
                ('status', models.CharField(blank=True, max_length=30, null=True)),
                ('createdBy', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
                ('disco', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='business_units', to='app.disco')),
            ],
            options={
                'db_table': 'BusinessUnits',
            },
        ),
        migrations.AddField(
            model_name='meterrequest',
            name='businessUnit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='app.businessunit'),
        ),
    ]



# Generated by Django 3.2.7 on 2022-07-03 19:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0013_auto_20220628_1815'),
    ]

    operations = [
        migrations.AddField(
            model_name='meterrequest',
            name='orderId',
            field=models.CharField(db_column='orderId', default='0000000000', max_length=30),
            preserve_default=False,
        ),
    ]



from django.db import models

from .user import User
from .work_order import WorkOrder
from .base import BaseModelAbstract


class Documentation(BaseModelAbstract, models.Model):
    url = models.URLField(blank=True, null=True)
    user = models.ForeignKey(User, models.SET_NULL,
                             blank=True, null=True, 
                             related_name="documentations")

    class Meta:
        db_table = 'Documentations'


class Document(BaseModelAbstract, models.Model):
    workOrder = models.ForeignKey(WorkOrder, models.SET_NULL,
                                  blank=True, null=True)
    reference = models.CharField(max_length=255, blank=True, null=True)
    filename = models.CharField(db_column='fileName', max_length=255,
                                blank=True, null=True)
    type = models.CharField(max_length=30, blank=True, null=True)

    class Meta:
        db_table = 'Documents'



import time

from django.db import models

from .user_address import UserAddress
from .base import BaseModelAbstract
from .user import User
from .work_order_service import WorkOrderServiceCategory
from .payment import PaymentVendor


class WorkOrder(BaseModelAbstract, models.Model):
    serviceSubCategory = models.ForeignKey(
        WorkOrderServiceCategory, models.SET_NULL,
        db_column='serviceSubCategory', blank=True, null=True)
    agent = models.ForeignKey(User, models.SET_NULL, blank=True, null=True, 
                              related_name="workorders_agent_set")
    address = models.TextField()
    longitude = models.CharField(max_length=30, default="0")
    latitude = models.CharField(max_length=30, default="0")
    # paymentType = models.ForeignKey(PaymentType, models.SET_NULL, null=True,
    #                                 blank=True)
    paymentVendor = models.ForeignKey(PaymentVendor, models.SET_NULL, 
                                      null=True, blank=True)
    description = models.TextField(blank=True, null=True)
    orderId = models.CharField(db_column='orderId', max_length=30,
                               blank=False, null=False)
    assessmentReport = models.TextField(
        db_column='assessmentReport', blank=True, null=True)
    completionReport = models.TextField(
        db_column='completionReport', blank=True, null=True)
    transactionReference = models.TextField(
        db_column='transactionReference', blank=True, null=True, 
        max_length=255
    )
    generalStatus = models.CharField(db_column='generalStatus', default='new',
                                     max_length=30)
    currentStatus = models.CharField(db_column='currentStatus',
                                     default='unAssigned', max_length=30)
    noteForAgent = models.TextField(db_column='noteForAgent', blank=True,
                                    null=True)
    additionalNote = models.TextField(db_column='additionalNote',
                                      blank=True, null=True)
    date = models.DateTimeField(blank=False, null=False)
    fee = models.DecimalField(max_digits=15, decimal_places=2, default=0)
    totalAmount = models.DecimalField(db_column='totalAmount',
                                      max_digits=15, decimal_places=2,
                                      default=0)
    actualServiceCharge = models.DecimalField(
        db_column='actualServiceCharge', max_digits=15, decimal_places=2,
        default=0)
    remainingServiceCharge = models.DecimalField(
        db_column='remainingServiceCharge', max_digits=15, decimal_places=2,
        default=0)
    remainingtotalAmount = models.DecimalField(
        db_column='remainingtotalAmount', max_digits=15, decimal_places=2,
        default=0)
    totalMaterialsFee = models.DecimalField(db_column='totalMaterialsFee',
                                            max_digits=15, decimal_places=2,
                                            default=0)
    isCommitmentFeePaid = models.BooleanField(db_column='isCommitmentFeePaid',
                                              default=False)
    agentEnroute = models.BooleanField(db_column='agentEnroute',
                                       default=False)
    agentArrived = models.BooleanField(db_column='agentArrived',
                                       default=False)
    isAssessmentCompleted = models.BooleanField(
        db_column='isAssessmentCompleted',
        default=False
    )
    paymentCompleted = models.BooleanField(db_column='paymentCompleted',
                                           default=False)
    jobStartedAt = models.DateTimeField(db_column='jobStartedAt',
                                        blank=True, null=True)
    jobCompletedAt = models.DateTimeField(db_column='jobCompletedAt',
                                          blank=True, null=True)
    isAgentJobComplete = models.BooleanField(db_column='isAgentJobComplete',
                                             blank=True, null=True)
    customerCompletionConfirmation = models.BooleanField(
        db_column='customerCompletionConfirmation', default=False)
    isAgentReview = models.BooleanField(db_column='isAgentReview',
                                        default=False)
    isCustomerReview = models.BooleanField(
        db_column='isCustomerReview', default=False
    )
    agentEnrouteAt = models.DateTimeField(db_column='agentEnrouteAt',
                                          blank=True, null=True)
    agentArrivedAt = models.DateTimeField(db_column='agentArrivedAt',
                                          blank=True, null=True)
    agentAssignedAt = models.DateTimeField(db_column='agentAssignedAt',
                                           blank=True, null=True)
    
    def save(self, keep_deleted=False, **kwargs):
        if not self.orderId:
            self.orderId = str(time.time()).split('.')[0]
        super(WorkOrder, self).save(keep_deleted=keep_deleted, **kwargs)

    class Meta:
        db_table = 'WorkOrders'



from django.db import models

from .work_order import WorkOrder
from .base import BaseModelAbstract


class WorkOrderMaterial(BaseModelAbstract, models.Model):
    workOrder = models.ForeignKey(WorkOrder, on_delete=models.SET_NULL,
                                  null=True, blank=True)
    item = models.UUIDField(blank=True, null=True)
    quantity = models.IntegerField(default=1)
    price = models.DecimalField(max_digits=15, decimal_places=2, default=0)
    description = models.CharField(max_length=255, blank=True, null=True)
    productName = models.TextField(db_column='productName', blank=True,
                                   null=True)  # Field name made lowercase.

    class Meta:
        db_table = 'WorkOrderMaterials'




from rest_framework.response import Response
from typing import Optional


class ApiResponse(Response):
    def __init__(self, msg: str, data: Optional = None, status: int = 200):
        resp = {
            "msg": msg,
            "data": data
        }
        super().__init__(data=resp, status=status)


class SuccessApiResponse(ApiResponse):
    def __init__(self, msg, data):
        super(SuccessApiResponse, self).__init__(msg, data)


class FailureApiResponse(ApiResponse):
    def __init__(self, msg, data=None):
        super(FailureApiResponse, self).__init__(msg, data, status=400)


class ServerErrorApiResponse(ApiResponse):
    def __init__(self):
        super(ServerErrorApiResponse, self).__init__("Server error",
                                                     status=500)



from django.db import models

from .base import BaseModelAbstract


class Product(BaseModelAbstract, models.Model):
    productName = models.CharField(max_length=255,
                                   blank=False, null=False)
    description = models.CharField(max_length=255, blank=False, null=False)
    quantity = models.IntegerField(default=1)
    price = models.DecimalField(max_digits=15, decimal_places=2, default=0)
    status = models.CharField(max_length=30, default='active', blank=True, 
                              null=True)

    class Meta:
        db_table = 'Products'



from django.contrib import admin
from .models import *
from django.contrib.auth import get_user_model
from django.contrib.auth.admin import UserAdmin as BaseUserAdmin

from .models.config import Config


class UserAdmin(BaseUserAdmin):
    fieldsets = (
        (None, {"fields": ("username", "email", "password")}),
        ("Personal info", {"fields": ("name", "phoneNumber")}),
        (
            "Permissions",
            {
                "fields": (
                    "is_active",
                    "is_staff",
                    "is_superuser",
                    "groups",
                    "user_permissions",
                ),
            },
        ),
        ("Important dates", {"fields": ("last_login", "date_joined")}),
    )
    add_fieldsets = (
        (
            None,
            {
                "classes": ("wide",),
                "fields": ("email", "username", "name", "password1", 
                           "password2"),
            },
        ),
    )
    list_display = ("username", "email", "name", "phoneNumber", "is_staff", 
                    "is_superuser")
    list_filter = ("is_staff", "is_superuser", "is_active", "groups")
    search_fields = ("email", "username", "name", "phoneNumber")
    ordering = ("email", "name", "phoneNumber")
    filter_horizontal = (
        "groups",
        "user_permissions",
    )


User_ = get_user_model()

admin.site.register(User_, UserAdmin)
admin.site.register(Card)
admin.site.register(Cart)
admin.site.register(Conversation)
admin.site.register(Message)
admin.site.register(Disco)
admin.site.register(BusinessUnit)
admin.site.register(Documentation)
admin.site.register(Document)
admin.site.register(Expertise)
admin.site.register(MeansOfIdentification)
admin.site.register(MeterRequest)
admin.site.register(NextOfKin)
admin.site.register(PaymentVendor)
# admin.site.register(Payment)
admin.site.register(Product)
admin.site.register(Purchase)
admin.site.register(Survey)
admin.site.register(TransactionLog)
admin.site.register(UserAddress)
admin.site.register(VerificationType)
admin.site.register(Verification)
admin.site.register(Wallet)
admin.site.register(WalletHistory)
admin.site.register(WorkOrder)
admin.site.register(WorkOrderMaterial)
admin.site.register(WorkOrderService)
admin.site.register(WorkOrderStatus)
admin.site.register(Config)
admin.site.register(PowerVend)



from django.db import models

from .work_order import WorkOrder
from .base import BaseModelAbstract

TYPES = (
    ('wallet-topup', 'wallet-topup'),
    ('wallet-withdrawal', 'wallet-withdrawal'),
    ('kyc-verification', 'kyc-verification'),
    ('meter-vend', 'meter-vend'),
    ('buy-meter', 'buy-meter'),
    ('service-order-commitment', 'service-order-commitment'),
    ('service-order-complete', 'service-order-complete'),
    ('others', 'others'),
)


class TransactionLog(BaseModelAbstract, models.Model):
    transactionRef = models.CharField(unique=True, max_length=255)
    paymentRef = models.CharField(db_column='paymentRef', max_length=255,
                                  blank=True, null=True)
    paymentVendor = models.ForeignKey(
        "PaymentVendor", models.SET_NULL,
        blank=True, null=True)
    workOrder = models.ForeignKey(WorkOrder, models.SET_NULL,
                                  blank=True, null=True)
    platform = models.CharField(max_length=30, blank=True, null=True)
    requestJson = models.JSONField(
        db_column='requestJSON', blank=True, null=True)
    responseJson = models.JSONField(
        db_column='responseJSON', blank=True, null=True)
    amount = models.DecimalField(decimal_places=2, max_digits=15, default=0)
    isPaid = models.BooleanField(default=False) 
    status = models.CharField(max_length=30, blank=True, null=True)
    transactionType = models.CharField(max_length=30, choices=TYPES)
    vendorStatus = models.CharField(max_length=30, blank=True, null=True)
    callbackJson = models.JSONField(db_column='callbackJSON', blank=True, 
                                    null=True)  # Field name made lowercase.
    verifyJson = models.JSONField(db_column='verifyJSON', blank=True, 
                                  null=True)  # Field name made lowercase.
    webhookJson = models.JSONField(db_column='webhookJSON', blank=True, 
                                   null=True)  # Field name made lowercase.

    class Meta:
        db_table = 'TransactionLogs'



from mojec_core.app.managers.firebase_manager import FirebaseManager
from mojec_core.app.managers.push_notification_manager import \
    PushNotificationManager

firebase_manager = FirebaseManager()
push_notification_manager = PushNotificationManager()




from django.db import models
from .base import BaseModelAbstract


class WorkOrderService(BaseModelAbstract, models.Model):
    name = models.TextField(blank=True, null=True)
    status = models.CharField(max_length=30, default='active', blank=True, 
                              null=True)

    class Meta:
        db_table = 'WorkOrderServices'

    def __str__(self):
        return self.name


class WorkOrderServiceCategory(BaseModelAbstract, models.Model):
    service = models.ForeignKey(
        WorkOrderService, models.SET_NULL, db_column='service',
        blank=True, null=True)
    name = models.CharField(max_length=255, blank=False, null=False)
    chargeType = models.CharField(db_column='chargeType', blank=True,
                                  null=True, max_length=30)
    commission = models.DecimalField(
        max_digits=15, decimal_places=2, default=0
    )
    serviceCharge = models.DecimalField(
        db_column='serviceCharge', max_digits=15,
        decimal_places=2, default=0
    )
    commitmentFee = models.DecimalField(
        db_column='commitmentFee', max_digits=15,
        decimal_places=2, default=0)
    status = models.CharField(max_length=30, default='active', blank=True, 
                              null=True)

    class Meta:
        db_table = 'WOServiceCategories'



import redis
import os


class BaseRedisManager:
    client = None

    def __init__(self, store):
        self.redis_host = os.getenv('REDIS_HOST')
        self.redis_port = os.getenv('REDIS_PORT', '6379')
        self.redis_password = os.getenv('REDIS_PASSWORD', None)
        self.config_store = store

    def connect(self):
        self.client = redis.Redis(host=self.redis_host,
                                  port=int(self.redis_port),
                                  password=self.redis_password)



import logging


def log_exception(source: str, exception: Exception):
    """
    To log exception to console
    usage: log_exception(MyClass, exception_object)
    
    :param source: 
    :param exception: 
    :return: 
    """
    logger = logging.getLogger(source)
    logger.exception(exception)



from django.db import models

from .base import BaseModelAbstract
from .cart import Cart
from .product import Product


class Purchase(BaseModelAbstract, models.Model):
    cart = models.ForeignKey(Cart, models.SET_NULL,
                             blank=True, null=True)
    product = models.ForeignKey(Product, models.SET_NULL,
                                blank=True, null=True)
    quantity = models.IntegerField(default=1)
    amount = models.DecimalField(max_digits=12, decimal_places=2, default=0)
    status = models.CharField(max_length=30, default='pending', blank=True, 
                              null=True)

    class Meta:
        db_table = 'Purchases'



from django.contrib.auth.models import AbstractUser
from django.db import models

from .base import BaseModelAbstract


class User(AbstractUser, BaseModelAbstract):
    """
        Overrides django's default auth model
    """
    first_name = None
    last_name = None
    USERNAME_FIELD = "email"
    REQUIRED_FIELDS = ["name", "username"]
    
    email = models.EmailField(unique=True, null=False, blank=False)
    name = models.CharField(max_length=255, blank=False, null=False)
    phoneNumber = models.CharField(
        db_column='phoneNumber', unique=True,
        max_length=11, blank=True, null=True)
    emailVerified = models.BooleanField(db_column='emailVerified', blank=True,
                                        null=True)
    phoneNumberVerified = models.BooleanField(db_column='phoneNumberVerified',
                                              blank=True,
                                              null=True)
    verified = models.BooleanField(blank=True, null=True)
    verificationMode = models.CharField(db_column='verificationMode',
                                        max_length=255, blank=True,
                                        null=True)
    platform = models.CharField(max_length=15, blank=True, null=True)
    active = models.BooleanField(blank=True, null=True)
    bankAccountNumber = models.CharField(db_column='bankAccountNumber',
                                         max_length=11, blank=True,
                                         null=True)  # Field name made
    isOnboardingComplete = models.BooleanField(
        db_column='isOnboardingComplete', default=False
    )
    onboardingStage = models.CharField(
        max_length=100,
        db_column='onboardingStage',
        blank=True, null=True
    )
    imageUrl = models.TextField(
        db_column='imageUrl', blank=True, null=True
    )
    bankAccountName = models.CharField(db_column='bankAccountName',
                                       max_length=255, blank=True,
                                       null=True)  # Field name made lowercase.
    bankCode = models.CharField(db_column='bankCode', max_length=10,
                                blank=True,
                                null=True)
    sbcId = models.UUIDField(blank=True, null=True)
    fcmToken = models.JSONField(
        db_column='fcmToken', blank=True, null=True
    )
    locationLatitude = models.FloatField(
        default=0
    )
    locationLongitude = models.FloatField(
        default=0
    )
    # KYC
    employerName = models.CharField(db_column='employerName', max_length=255,
                                    blank=True, null=True)
    employerAddress = models.TextField(db_column='employerAddress',
                                       blank=True, null=True)
    landlordName = models.CharField(db_column='landlordName', max_length=255,
                                    blank=True, null=True)
    landlordAddress = models.TextField(db_column='landlordAddress',
                                       blank=True, null=True)
    idNumber = models.CharField(db_column='idNumber', max_length=30,
                                blank=True, null=True)
    idType = models.CharField(db_column='idType', max_length=50,
                              blank=True, null=True)
    bvn = models.CharField(max_length=11, blank=True, null=True)

    class Meta:
        db_table = 'Users'



# Generated by Django 3.2.7 on 2022-07-12 22:49

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0015_meterrequest_status'),
    ]

    operations = [
        migrations.CreateModel(
            name='PowerVend',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('deletedViaCascade', models.BooleanField(default=False, editable=False)),
                ('uid', models.UUIDField(default=uuid.uuid4, editable=False)),
                ('deleted', models.BooleanField(default=False)),
                ('deletedById', models.UUIDField(blank=True, null=True)),
                ('deletedAt', models.DateTimeField(blank=True, db_column='deletedAt', null=True)),
                ('createdAt', models.DateTimeField(auto_now_add=True, db_column='createdAt')),
                ('updatedAt', models.DateTimeField(auto_now=True, db_column='updatedAt')),
                ('meter_number', models.CharField(max_length=250)),
                ('red_code', models.CharField(max_length=250)),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=15)),
                ('status', models.CharField(blank=True, default='new', max_length=30, null=True)),
                ('token', models.CharField(max_length=250)),
                ('action', models.CharField(max_length=250)),
                ('createdBy', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'PowerVend',
            },
        ),
    ]



from django.db import models

from mojec_core.app.models import User

SERVICES = (
    ("msh", "msh"),
    ("payment", "payment"),
    ("inventory", "inventory"),
    ("customer", "customer"),
)


class Config(models.Model):
    service = models.CharField(max_length=50, choices=SERVICES, null=False)
    key = models.CharField(max_length=50, null=False, unique=True)
    value = models.CharField(max_length=100, null=False)
    date_created = models.DateTimeField(auto_now_add=True)
    date_updated = models.DateTimeField(auto_now=True)
    last_updated_by = models.ForeignKey(User, models.SET_NULL,
                                        null=True, blank=True)

    def __str__(self):
        return f"{self.key}: {self.value}"



from setuptools import setup, find_packages

VERSION = '0.1.8'
DESCRIPTION = 'Mojec core package'
LONG_DESCRIPTION = 'Package that holds all models and common ' \
                   'functions/classes of Mojec project'

# Setting up
setup(
    # the name must match the folder name 'verysimplemodule'
    name="mojec_core",
    version=VERSION,
    author="Folayemi Bello",
    author_email="<bello.folayemi.az@gmail.com>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    package_data={'': ['firebase.json']},
    include_package_data=True,
    install_requires=["django", "djangorestframework",
                      "djangorestframework-simplejwt", "drf-yasg",
                      "python-dotenv", "django-safedelete", "firebase-admin",
                      "django-cors-headers", "redis", "onesignal-sdk"],
    # add any
    # additional packages that
    # needs to be installed along with your package. Eg: 'caer'

    keywords=['python', 'mojec'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",

    ]
)



from django.db import models

from .work_order import WorkOrder
from .transaction import TransactionLog
from .base import BaseModelAbstract
from .user import User


class Wallet(BaseModelAbstract, models.Model):
    createdBy = None
    user = models.OneToOneField(User, models.CASCADE, null=False, 
                                blank=False, related_name="wallet")
    balance = models.DecimalField(default=0, max_digits=15, decimal_places=2)

    class Meta:
        db_table = 'Wallets'


TYPES = (
    ("earnings", "earnings"),
    ("deposit", "deposit"),
    ("withdrawal", "withdrawal"),
    ("payment", "payment"),
)


class WalletHistory(BaseModelAbstract, models.Model):
    workOrder = models.ForeignKey(WorkOrder, models.SET_NULL,
                                  blank=True, null=True)
    transactionLog = models.ForeignKey(TransactionLog, models.SET_NULL,
                                       blank=True, null=True)
    wallet = models.ForeignKey(Wallet, models.SET_NULL, blank=True, null=True)
    amount = models.DecimalField(default=0, max_digits=15, decimal_places=2)
    balanceBefore = models.DecimalField(default=0, max_digits=15,
                                        decimal_places=2)
    balanceAfter = models.DecimalField(default=0, max_digits=15,
                                       decimal_places=2)
    description = models.CharField(max_length=255, blank=True, null=True)
    type = models.CharField(max_length=30, choices=TYPES, blank=True,
                            null=True)
    isSuccessful = models.BooleanField(db_column='isSuccessful', default=False)

    class Meta:
        db_table = 'WalletHistories'



import time

from django.db import models

from .base import BaseModelAbstract
from .disco import Disco, BusinessUnit


class MeterRequest(BaseModelAbstract, models.Model):
    disco = models.ForeignKey(Disco, models.SET_NULL,
                              blank=True, null=True)
    businessUnit = models.ForeignKey(BusinessUnit, models.SET_NULL,
                                     blank=True, null=True)
    quantity = models.IntegerField(default=1)
    phone = models.CharField(max_length=11, blank=True, null=True)
    account = models.CharField(max_length=255, blank=True, null=True)
    orderId = models.CharField(db_column='orderId', max_length=30,
                               blank=False, null=False)
    address = models.TextField(blank=True, null=True)
    status = models.CharField(max_length=15, default='new')

    class Meta:
        db_table = 'MeterRequests'

    def save(self, keep_deleted=False, **kwargs):
        if not self.orderId:
            self.orderId = str(time.time()).split('.')[0]
        super(MeterRequest, self).save(keep_deleted=keep_deleted, **kwargs)
